@@ -13,8 +13,8 @@ use std::borrow::Cow;
 use std::sync::Arc;
 use std::sync::mpsc::RecvError;
 use cogo::std::io::TryStream;
-use cogo::std::sync::mpmc;
-use cogo::std::sync::mpmc::Receiver;
+use cogo::std::sync::channel;
+use cogo::std::sync::channel::Receiver;
 use cdbc::database::{Database, HasStatement};
 use cdbc::io::chan_stream::ChanStream;
 use cdbc::utils::statement_cache::StatementCache;
